# Generated by Django 2.1 on 2019-05-07 14:02

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0085_auto_20190506_1028'),
        ('djconnectwise', '0085_auto_20190430_1004'),
    ]

    operations = [
    ]
