# Generated by Django 3.1.7 on 2021-07-23 11:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0152_auto_20210722_1224'),
    ]

    operations = [
        migrations.AddField(
            model_name='ticket',
            name='tasks_completed',
            field=models.PositiveSmallIntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='tasks_total',
            field=models.PositiveSmallIntegerField(blank=True, null=True),
        ),
    ]
