# Generated by Django 2.1.14 on 2020-09-17 19:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0123_project_description'),
    ]

    operations = [
        migrations.AddField(
            model_name='ticket',
            name='lag_days',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='lag_non_working_days_flag',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='ticket',
            name='predecessor_id',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='predecessor_type',
            field=models.CharField(blank=True, choices=[('Ticket', 'Ticket'), ('Phase', 'Phase')], max_length=10, null=True),
        ),
    ]
