# Generated by Django 3.1.7 on 2021-07-28 14:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0154_auto_20210726_1252'),
        ('djconnectwise', '0153_auto_20210723_1104'),
    ]

    operations = [
    ]
