# Generated by Django 2.0 on 2019-01-31 22:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0082_auto_20190125_1109'),
    ]

    operations = [
        migrations.DeleteModel(
            name='CallBackEntry',
        ),
    ]
