# Generated by Django 2.0 on 2018-12-03 10:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0077_item_subtype_type'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='subtype',
            options={'verbose_name': 'Subtype', 'verbose_name_plural': 'Subtypes'},
        ),
    ]
