# Generated by Django 2.1.14 on 2020-06-09 15:14

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0116_auto_20200522_1107'),
    ]

    operations = [
        migrations.AddField(
            model_name='connectwiseboard',
            name='project_flag',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='project',
            name='board',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djconnectwise.ConnectWiseBoard'),
        ),
        migrations.AddField(
            model_name='project',
            name='percent_complete',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=3, null=True),
        ),
    ]
