# Generated by Django 3.1.2 on 2020-10-08 20:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0129_auto_20201005_1054'),
    ]

    operations = [
        migrations.CreateModel(
            name='ActivityStatusTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_activitystatus',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.activitystatus',),
        ),
        migrations.CreateModel(
            name='ActivityTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_activity',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.activity',),
        ),
        migrations.CreateModel(
            name='ActivityTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_activitytype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.activitytype',),
        ),
        migrations.CreateModel(
            name='AgreementTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_agreement',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.agreement',),
        ),
        migrations.CreateModel(
            name='BoardStatusTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_boardstatus',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.boardstatus',),
        ),
        migrations.CreateModel(
            name='CalendarTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_calendar',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.calendar',),
        ),
        migrations.CreateModel(
            name='CompanyStatusTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_companystatus',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.companystatus',),
        ),
        migrations.CreateModel(
            name='CompanyTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_company',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.company',),
        ),
        migrations.CreateModel(
            name='CompanyTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_companytype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.companytype',),
        ),
        migrations.CreateModel(
            name='ConnectWiseBoardTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_connectwiseboard',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.connectwiseboard',),
        ),
        migrations.CreateModel(
            name='HolidayListTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_holidaylist',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.holidaylist',),
        ),
        migrations.CreateModel(
            name='HolidayTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_holiday',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.holiday',),
        ),
        migrations.CreateModel(
            name='ItemTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_item',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.item',),
        ),
        migrations.CreateModel(
            name='LocationTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_location',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.location',),
        ),
        migrations.CreateModel(
            name='MemberTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_member',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.member',),
        ),
        migrations.CreateModel(
            name='MyCompanyOtherTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_mycompanyother',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.mycompanyother',),
        ),
        migrations.CreateModel(
            name='OpportunityNoteTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_opportunitynote',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.opportunitynote',),
        ),
        migrations.CreateModel(
            name='OpportunityPriorityTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_opportunitypriority',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.opportunitypriority',),
        ),
        migrations.CreateModel(
            name='OpportunityStageTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_opportunitystage',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.opportunitystage',),
        ),
        migrations.CreateModel(
            name='OpportunityStatusTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_opportunitystatus',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.opportunitystatus',),
        ),
        migrations.CreateModel(
            name='OpportunityTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_opportunity',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.opportunity',),
        ),
        migrations.CreateModel(
            name='OpportunityTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_opportunitytype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.opportunitytype',),
        ),
        migrations.CreateModel(
            name='ProjectPhaseTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_projectphase',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.projectphase',),
        ),
        migrations.CreateModel(
            name='ProjectStatusTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_projectstatus',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.projectstatus',),
        ),
        migrations.CreateModel(
            name='ProjectTeamMemberTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_projectteammember',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.projectteammember',),
        ),
        migrations.CreateModel(
            name='ProjectTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_project',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.project',),
        ),
        migrations.CreateModel(
            name='ProjectTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_projecttype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.projecttype',),
        ),
        migrations.CreateModel(
            name='SalesProbabilityTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_salesprobability',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.salesprobability',),
        ),
        migrations.CreateModel(
            name='ScheduleEntryTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_scheduleentry',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.scheduleentry',),
        ),
        migrations.CreateModel(
            name='ScheduleStatusTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_schedulestatus',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.schedulestatus',),
        ),
        migrations.CreateModel(
            name='ScheduleTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_scheduletype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.scheduletype',),
        ),
        migrations.CreateModel(
            name='ServiceNoteTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_servicenote',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.servicenote',),
        ),
        migrations.CreateModel(
            name='SlaPriorityTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_slapriority',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.slapriority',),
        ),
        migrations.CreateModel(
            name='SlaTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_sla',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.sla',),
        ),
        migrations.CreateModel(
            name='SubTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_subtype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.subtype',),
        ),
        migrations.CreateModel(
            name='TeamTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_team',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.team',),
        ),
        migrations.CreateModel(
            name='TerritoryTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_territory',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.territory',),
        ),
        migrations.CreateModel(
            name='TicketPriorityTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_ticketpriority',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.ticketpriority',),
        ),
        migrations.CreateModel(
            name='TicketTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_ticket',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.ticket',),
        ),
        migrations.CreateModel(
            name='TimeEntryTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_timeentry',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.timeentry',),
        ),
        migrations.CreateModel(
            name='TypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_type',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.type',),
        ),
        migrations.CreateModel(
            name='WorkRoleTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_workrole',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.workrole',),
        ),
        migrations.CreateModel(
            name='WorkTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_worktype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.worktype',),
        ),
    ]
