# Generated by Django 2.1 on 2019-07-12 14:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0090_auto_20190711_1114'),
    ]

    operations = [
        migrations.AddField(
            model_name='worktype',
            name='bill_time',
            field=models.CharField(blank=True, choices=[('Billable', 'Billable'), ('DoNotBill', 'Do Not Bill'), ('NoCharge', 'No Charge')], max_length=50, null=True),
        ),
    ]
