# Generated by Django 2.0 on 2018-09-10 16:29

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0074_auto_20180827_1241'),
    ]

    operations = [
        migrations.AlterField(
            model_name='timeentry',
            name='company',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='djconnectwise.Company'),
        ),
    ]
