# Generated by Django 3.1 on 2020-09-24 13:20

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0125_auto_20200923_0952'),
    ]

    operations = [
        migrations.AlterField(
            model_name='activity',
            name='company',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.company'),
        ),
        migrations.AlterField(
            model_name='boardstatus',
            name='board',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.connectwiseboard'),
        ),
        migrations.AlterField(
            model_name='project',
            name='board',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.connectwiseboard'),
        ),
        migrations.AlterField(
            model_name='scheduleentry',
            name='activity_object',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.activity'),
        ),
        migrations.AlterField(
            model_name='scheduleentry',
            name='member',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.member'),
        ),
        migrations.AlterField(
            model_name='scheduleentry',
            name='ticket_object',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.ticket'),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='board',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.connectwiseboard'),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='project',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='project_tickets', to='djconnectwise.project'),
        ),
        migrations.AlterField(
            model_name='timeentry',
            name='company',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djconnectwise.company'),
        ),
    ]
