# Generated by Django 3.1.2 on 2020-12-15 13:04

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0140_auto_20201209_1033'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='contact',
            name='address_line1',
        ),
        migrations.RemoveField(
            model_name='contact',
            name='address_line2',
        ),
        migrations.RemoveField(
            model_name='contact',
            name='city',
        ),
        migrations.RemoveField(
            model_name='contact',
            name='state_identifier',
        ),
        migrations.RemoveField(
            model_name='contact',
            name='zip',
        ),
    ]
